==> nextcloud-app-calendar-1%3A5.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/br.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Un troc'h dic'hortoz zo c'hoarvezet en dalc'h implijer",
    "Provided email-address is not valid" : "Direizh eo ar chomlec'h postel",
    "%s has published the calendar »%s«" : "%s en deus embannet un deiziataer »%s«",
    "Unexpected error sending email. Please contact your administrator." : "C'hoarvezet ez eus ur fazi dic'hortoz en ur gas ar postel. Kit e darempred gant ho merour.",
    "Hello," : "Demat deoc'h,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kemenn a reomp deoc'h ez eus bet %s embannet un deiziataer » gant %s«",
    "Open »%s«" : "Digeriñ  »%s«",
    "Cheers!" : "A galon !",
    "Upcoming events" : "Darvoudoù da zont",
    "Calendar" : "Deiziataer",
    "Confirm" : "Kadarnañ",
    "A Calendar app for Nextcloud" : "Un arload Deiziataerioù evit Nextcloud",
    "Previous day" : "Deizioù kent",
    "Previous week" : "Sizhun kent",
    "Previous month" : "Miz kent",
    "Next day" : "Deiz war-lerc'h",
    "Next week" : "Sizhun a zeu",
    "Next month" : "Miz a zeu",
    "Today" : "Hiziv",
    "Day" : "Deiz",
    "Week" : "Sizhun",
    "Month" : "Miz",
    "List" : "Roll",
    "Preview" : "Ragwell",
    "Copy link" : "Kopiañ al liamm",
    "Edit" : "Cheñch",
    "Delete" : "Dilemel",
    "Create new" : "Krouiñ unan nevez",
    "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
    "Untitled calendar" : "Deiziataer hep titl",
    "Shared with you by" : "Rannet deoc'h gant",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
    "Calendars" : "Deiziadurioù",
    "New calendar" : "Deizataer nevez",
    "Creating calendar …" : "Krouiñ un deizataer ...",
    "New calendar with task list" : "Deizataer nevez gant ur roll ober",
    "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
    "Creating subscription …" : "Krouiñ ur goumanant ...",
    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
    "Copy subscription link" : "Eilañ al liamm koumanantiñ",
    "Copying link …" : "Oc'h eilañ al liamm  ...",
    "Copied link" : "Liamm eilet",
    "Could not copy link" : "N'eus ket bet gallet eilañ al liamm",
    "Empty trash bin" : "Pod-lastez goullo",
    "Name" : "Anv",
    "Deleted" : "Lamet",
    "Restore" : "Adkrouiñ",
    "Delete permanently" : "Lamet da viken",
    "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
    "An error occurred, unable to publish calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket embann an deiziataer.",
    "An error occurred, unable to send email." : "C'hoarvezet ez eus ur fazi, ne c'haller ket kas ar postel",
    "Embed code copied to clipboard." : "Eilet eo bet ar c'hod enframmañ er golver",
    "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
    "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
    "Share link" : "Lodañ al liamm",
    "Copy public link" : "Eilañ al liamm foran",
    "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
    "Enter one address" : "Lakait ur chomlec'h",
    "Sending email …" : "O kas ar postel  ... ",
    "Copy embedding code" : "Eilañ ar c'hod enframmañ",
    "Copying code …" : "Oc'h eilañ ar c'hod ...",
    "Copied code" : "Kod eilet",
    "Could not copy code" : "N'eus ket bet gallet eilañ ar c'hod",
    "Delete share link" : "Dilamet eo bet al liamm lodañ",
    "Deleting share link …" : "O tilemel al liamm lodañ...",
    "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
    "can edit" : "posuple eo embann",
    "Unshare with {displayName}" : "Dirannañ gant {displayName}",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "Unshare from me" : "Paouez da lodañ ganin",
    "Save" : "Enrollañ",
    "Import calendars" : "Emporzhiañ deizataerioù",
    "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
    "Filename" : "Anv restr",
    "Calendar to import into" : "Deizataer de emporzhiañ e-barzh",
    "Cancel" : "Arrest",
    "_Import calendar_::_Import calendars_" : ["Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer"],
    "{filename} could not be parsed" : "{filename} na c'hell ket bezhañ dielfennet",
    "No valid files found, aborting import" : "Restr mat kavet ebet, arrestet e vez an emporzhiañ",
    "Import partially failed. Imported {accepted} out of {total}." : "Emporzhiañ damc'hwitet. Emporzhiet {accepted} diwar {total}.",
    "List view" : "Gwelidik listenn",
    "Actions" : "Oberoù",
    "Update" : "Hizivaat",
    "Location" : "Lec'hiadur",
    "Description" : "Deskrivadur",
    "Add" : "Ouzhpennañ",
    "Monday" : "Lun",
    "Your email address" : "O chom-lec'h postel",
    "Select conversation" : "Choaz un diviz",
    "Notification" : "Kemennadenn",
    "Email" : "Postel",
    "hours" : "eur",
    "days" : "devezh",
    "Delete file" : "Dilemel ar restr",
    "Available" : "Vak",
    "Not available" : "Divak",
    "Free" : "Digoust",
    "Busy" : "O labourat",
    "Unknown" : "Dianv",
    "Done" : "Graet",
    "Accept" : "Asantiñ",
    "Tentative" : "Taol-esae",
    "Remove group" : "Lemel strollad",
    "never" : "james",
    "after" : "goude",
    "first" : "kentañ",
    "Global" : "Hollek",
    "Personal" : "Personel",
    "Details" : "Munudoù",
    "Close" : "Serriñ",
    "Daily" : "Pemdeziek",
    "Weekly" : "Sizhuniek",
    "Monthly" : "Miziek",
    "Yearly" : "Bloaziek",
    "_Every %n day_::_Every %n days_" : ["Bemdez","Bep %n zevezh","Bep %n devezh","Bep %n devezh","Bep %n devezh"],
    "_Every %n week_::_Every %n weeks_" : ["Bep sizhun","Bep %n sizhun","Bep %n sizhun","Bep %n sizhun","Bep %n sizhun"],
    "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
    "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
    "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
    "third" : "trede",
    "%n more" : "%n ouzhpenn",
    "No events to display" : "Darvoud ebet da ziskouez",
    "No events" : "Darvoud ebet",
    "Other" : "All",
    "When shared show" : "Diskouez pa vez lodet",
    "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
    "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
    "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
    "The visibility of this event in shared calendars." : "Gweluster an darvoud-mañ en deiziataerioù lodet.",
    "Add a location" : "Ouzhpennañ ul lec'hiadur",
    "Status" : "Statud",
    "Confirmed" : "Kadarnaet",
    "Canceled" : "Nullet",
    "Confirmation about the overall status of the event." : "Kadarnaat statud hollek an darvoud.",
    "Show as" : "Diskouez evel",
    "Take this event into account when calculating free-busy information." : "Kemer an darvoud-mañ e kont pa vez jedet titouroù pres-dibres",
    "Categories" : "Rummadoù",
    "Categories help you to structure and organize your events." : "Ar rummadoù a harp ac'hanoc'h da aozañ ha da frammañ ho tarvoudoù",
    "Search or add categories" : "Klask hag ouzhpennañ rummadoù",
    "Add this as a new category" : "Ouzhpennañ an dra-se evel ur rummad nevez",
    "Custom color" : "Liv personelaet",
    "Special color of this event. Overrides the calendar-color." : "Liv dibar evit an darvoud-mañ. Diverkañ liv an deiziataer",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
    "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
    "Imported {filename}" : "Enporzhiet {filename}",
    "[Today]" : "[Hiziv]",
    "[Tomorrow]" : "[Warc'hoazh]",
    "[Yesterday]" : "[Dec'h]",
    "Add a description" : "Ouzhpennañ un deskrivadur",
    "Chat room for event" : "Sal-flapiñ evit un darvoud"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-app-calendar-1%3A5.3.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/br.js <==
OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Un troc'h dic'hortoz zo c'hoarvezet en dalc'h implijer",
    "Provided email-address is not valid" : "Direizh eo ar chomlec'h postel",
    "%s has published the calendar »%s«" : "%s en deus embannet un deiziataer »%s«",
    "Unexpected error sending email. Please contact your administrator." : "C'hoarvezet ez eus ur fazi dic'hortoz en ur gas ar postel. Kit e darempred gant ho merour.",
    "Hello," : "Demat deoc'h,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Kemenn a reomp deoc'h ez eus bet %s embannet un deiziataer » gant %s«",
    "Open »%s«" : "Digeriñ  »%s«",
    "Cheers!" : "A galon !",
    "Upcoming events" : "Darvoudoù da zont",
    "Calendar" : "Deiziataer",
    "Confirm" : "Kadarnañ",
    "Date:" : "Deiziad:",
    "A Calendar app for Nextcloud" : "Un arload Deiziataerioù evit Nextcloud",
    "Previous day" : "Deizioù kent",
    "Previous week" : "Sizhun kent",
    "Previous month" : "Miz kent",
    "Next day" : "Deiz war-lerc'h",
    "Next week" : "Sizhun a zeu",
    "Next month" : "Miz a zeu",
    "Today" : "Hiziv",
    "Day" : "Deiz",
    "Week" : "Sizhun",
    "Month" : "Miz",
    "List" : "Roll",
    "Preview" : "Ragwell",
    "Copy link" : "Kopiañ al liamm",
    "Edit" : "Cheñch",
    "Delete" : "Dilemel",
    "Create new" : "Krouiñ unan nevez",
    "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
    "Untitled calendar" : "Deiziataer hep titl",
    "Shared with you by" : "Rannet deoc'h gant",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
    "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Lakait ul liamm mat (o kregiñ gant http://, https://, webcal://, or webcals://)",
    "Calendars" : "Deiziataerioù",
    "New calendar" : "Deizataer nevez",
    "Creating calendar …" : "Krouiñ un deizataer ...",
    "New calendar with task list" : "Deizataer nevez gant ur roll ober",
    "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
    "Creating subscription …" : "Krouiñ ur goumanant ...",
    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
    "Copy subscription link" : "Eilañ al liamm koumanantiñ",
    "Copying link …" : "Oc'h eilañ al liamm  ...",
    "Copied link" : "Liamm eilet",
    "Could not copy link" : "N'eus ket bet gallet eilañ al liamm",
    "Empty trash bin" : "Pod-lastez goullo",
    "Name" : "Anv",
    "Deleted" : "Dilamet",
    "Restore" : "Adkrouiñ",
    "Delete permanently" : "Lamet da viken",
    "Could not update calendar order." : "Dibosupl eo adnevesaat urzh an deizataerioù",
    "Hidden" : "Koachet",
    "An error occurred, unable to publish calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket embann an deiziataer.",
    "An error occurred, unable to send email." : "C'hoarvezet ez eus ur fazi, ne c'haller ket kas ar postel",
    "Embed code copied to clipboard." : "Eilet eo bet ar c'hod enframmañ er golver",
    "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
    "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
    "Share link" : "Lodañ al liamm",
    "Copy public link" : "Eilañ al liamm foran",
    "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
    "Enter one address" : "Lakait ur chomlec'h",
    "Sending email …" : "O kas ar postel  ... ",
    "Copy embedding code" : "Eilañ ar c'hod enframmañ",
    "Copying code …" : "Oc'h eilañ ar c'hod ...",
    "Copied code" : "Kod eilet",
    "Could not copy code" : "N'eus ket bet gallet eilañ ar c'hod",
    "Delete share link" : "Dilamet eo bet al liamm lodañ",
    "Deleting share link …" : "O tilemel al liamm lodañ...",
    "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
    "can edit" : "posuple eo embann",
    "Unshare with {displayName}" : "Dirannañ gant {displayName}",
    "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
    "No users or groups" : "Implijourienn pe strodadoù ebet",
    "Unshare from me" : "Paouez da lodañ ganin",
    "Save" : "Enrollañ",
    "Import calendars" : "Emporzhiañ deizataerioù",
    "Please select a calendar to import into …" : "Choazit un deizataer de emporzhiañ e-barzh ...",
    "Filename" : "Anv restr",
    "Calendar to import into" : "Deizataer de emporzhiañ e-barzh",
    "Cancel" : "Nullañ",
    "_Import calendar_::_Import calendars_" : ["Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer"],
    "{filename} could not be parsed" : "{filename} na c'hell ket bezhañ dielfennet",
    "No valid files found, aborting import" : "Restr mat kavet ebet, arrestet e vez an emporzhiañ",
    "Import partially failed. Imported {accepted} out of {total}." : "Emporzhiañ damc'hwitet. Emporzhiet {accepted} diwar {total}.",
    "Automatic" : "Otomatek",
    "List view" : "Gwelidik listenn",
    "Actions" : "Oberoù",
    "Update" : "Hizivaat",
    "Location" : "Lec'hiadur",
    "Description" : "Deskrivadur",
    "Add" : "Ouzhpennañ",
    "Monday" : "Lun",
    "Wednesday" : "Merc'her",
    "Friday" : "Gwener",
    "Sunday" : "Sul",
    "Your email address" : "O chom-lec'h postel",
    "Select conversation" : "Choaz un diviz",
    "Notification" : "Kemennadenn",
    "Email" : "Postel",
    "hours" : "eur",
    "days" : "devezh",
    "Delete file" : "Dilemel ar restr",
    "Available" : "Vak",
    "Not available" : "Divak",
    "Free" : "Digoust",
    "Busy" : "O labourat",
    "Unknown" : "Dianv",
    "Done" : "Graet",
    "Accept" : "Asantiñ",
    "Tentative" : "Taol-esae",
    "Remove group" : "Lemel strollad",
    "never" : "james",
    "after" : "goude",
    "first" : "kentañ",
    "Global" : "Hollek",
    "Personal" : "Personel",
    "Details" : "Munudoù",
    "Close" : "Serriñ",
    "Daily" : "Pemdeziek",
    "Weekly" : "Sizhuniek",
    "Monthly" : "Miziek",
    "Yearly" : "Bloaziek",
    "_Every %n day_::_Every %n days_" : ["Bemdez","Bep %n zevezh","Bep %n devezh","Bep %n devezh","Bep %n devezh"],
    "_Every %n week_::_Every %n weeks_" : ["Bep sizhun","Bep %n sizhun","Bep %n sizhun","Bep %n sizhun","Bep %n sizhun"],
    "_Every %n month_::_Every %n months_" : ["Bep miz","Bep %n viz","Bep %n miz","Bep %n miz","Bep %n miz"],
    "_Every %n year_::_Every %n years_" : ["Bep bloaz","Bep %n vloaz","Bep %n bloaz","Bep %n bloaz","Bep %n bloaz"],
    "_on {weekday}_::_on {weekdays}_" : ["d'al {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}","d'ar {weekday}"],
    "third" : "trede",
    "W" : "S",
    "%n more" : "%n ouzhpenn",
    "No events to display" : "Darvoud ebet da ziskouez",
    "No events" : "Darvoud ebet",
    "Other" : "All",
    "When shared show" : "Diskouez pa vez lodet",
    "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
    "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
    "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
    "The visibility of this event in shared calendars." : "Gweluster an darvoud-mañ en deiziataerioù lodet.",
    "Add a location" : "Ouzhpennañ ul lec'hiadur",
    "Status" : "Statud",
    "Confirmed" : "Kadarnaet",
    "Canceled" : "Nullet",
    "Confirmation about the overall status of the event." : "Kadarnaat statud hollek an darvoud.",
    "Show as" : "Diskouez evel",
    "Take this event into account when calculating free-busy information." : "Kemer an darvoud-mañ e kont pa vez jedet titouroù pres-dibres",
    "Categories" : "Rummadoù",
    "Categories help you to structure and organize your events." : "Ar rummadoù a harp ac'hanoc'h da aozañ ha da frammañ ho tarvoudoù",
    "Search or add categories" : "Klask hag ouzhpennañ rummadoù",
    "Add this as a new category" : "Ouzhpennañ an dra-se evel ur rummad nevez",
    "Custom color" : "Liv personelaet",
    "Special color of this event. Overrides the calendar-color." : "Liv dibar evit an darvoud-mañ. Diverkañ liv an deiziataer",
    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
    "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
    "Imported {filename}" : "Enporzhiet {filename}",
    "[Today]" : "[Hiziv]",
    "[Tomorrow]" : "[Warc'hoazh]",
    "[Yesterday]" : "[Dec'h]",
    "in {monthNames}" : "e {monthNames}",
    "Add a description" : "Ouzhpennañ un deskrivadur",
    "Chat room for event" : "Sal-flapiñ evit un darvoud"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
